@@ -1,30 +1,32 @@
 from datetime import date
 import sys
 
-# prereq issues can be signaled with ImportError, so no try needed
+# Prereq issues can be signaled with ImportError, so no try needed
 import sqlalchemy, sqlalchemy.orm
 import Bcfg2.Server.Admin
 import Bcfg2.Server.Snapshots
 import Bcfg2.Server.Snapshots.model
 from Bcfg2.Server.Snapshots.model import Snapshot, Client, Metadata, Base, \
      File, Group, Package, Service
+# Compatibility import
+from Bcfg2.Bcfg2Py3k import u_str
 
 class Snapshots(Bcfg2.Server.Admin.Mode):
     __shorthelp__ = "Interact with the Snapshots system"
-    __longhelp__ = (__shorthelp__)
+    __longhelp__ = (__shorthelp__ + "\n\nbcfg2-admin snapshots init"
+                                    "\nbcfg2-admin query qtype\n")
     __usage__ = ("bcfg2-admin snapshots [init|query qtype]")
 
-    q_dispatch = {'client':Client,
-                  'group':Group,
-                  'metadata':Metadata,
-                  'package':Package,
-                  'snapshot':Snapshot}
+    q_dispatch = {'client':   Client,
+                  'group':    Group,
+                  'metadata': Metadata,
+                  'package':  Package,
+                  'snapshot': Snapshot}
 
-    def __init__(self, configfile):
-        Bcfg2.Server.Admin.Mode.__init__(self, configfile)
-        #self.session = Bcfg2.Server.Snapshots.setup_session(debug=True)
-        self.session = Bcfg2.Server.Snapshots.setup_session(configfile)
-        self.cfile = configfile
+    def __init__(self, setup):
+        Bcfg2.Server.Admin.Mode.__init__(self, setup)
+        self.session = Bcfg2.Server.Snapshots.setup_session(self.configfile)
+        self.cfile = self.configfile
 
     def __call__(self, args):
         Bcfg2.Server.Admin.Mode.__call__(self, args)
@@ -70,7 +72,7 @@ class Snapshots(Bcfg2.Server.Admin.Mode):
             session.commit()
         elif args[0] == 'dump':
             client = args[1]
-            snap = Snapshot.get_current(self.session, unicode(client))
+            snap = Snapshot.get_current(self.session, u_str(client))
             if not snap:
                 print("Current snapshot for %s not found" % client)
                 sys.exit(1)
@@ -104,7 +106,7 @@ class Snapshots(Bcfg2.Server.Admin.Mode):
                     print("Usage: bcfg2-admin snapshots -b <client>")
                     return
                 client = args[2]
-                snap = Snapshot.get_current(self.session, unicode(client))
+                snap = Snapshot.get_current(self.session, u_str(client))
                 if not snap:
                     print("Current snapshot for %s not found" % client)
                     sys.exit(1)
@@ -127,7 +129,7 @@ class Snapshots(Bcfg2.Server.Admin.Mode):
             elif '-e' in args[1:]:
                 # Query a single host for extra entries
                 client = args[2]
-                snap = Snapshot.get_current(self.session, unicode(client))
+                snap = Snapshot.get_current(self.session, u_str(client))
                 if not snap:
                     print("Current snapshot for %s not found" % client)
                     sys.exit(1)
