@@ -7,6 +7,8 @@ import select
 import sys
 import threading
 import time
+from traceback import format_exc
+
 try:
     import lxml.etree
 except ImportError:
@@ -15,6 +17,7 @@ except ImportError:
 
 from Bcfg2.Component import Component, exposed
 from Bcfg2.Server.Plugin import PluginInitError, PluginExecutionError
+import Bcfg2.Server
 import Bcfg2.Server.FileMonitor
 import Bcfg2.Server.Plugins.Metadata
 # Compatibility imports
@@ -69,10 +72,9 @@ class Core(Component):
         try:
             self.fam = Bcfg2.Server.FileMonitor.available[filemonitor]()
         except IOError:
-            logger.error("Failed to instantiate fam driver %s" % filemonitor,
-                         exc_info=1)
-            raise CoreInitError("failed to instantiate fam driver (used %s)" % \
-                                filemonitor)
+            msg = "Failed to instantiate fam driver %s" % filemonitor
+            logger.error(msg, exc_info=1)
+            raise CoreInitError(msg)
         self.pubspace = {}
         self.cfile = cfile
         self.cron = {}
@@ -240,12 +242,12 @@ class Core(Component):
                 self.Bind(entry, metadata)
             except PluginExecutionError, exc:
                 if 'failure' not in entry.attrib:
-                    entry.set('failure', 'bind error: %s' % exc)
+                    entry.set('failure', 'bind error: %s' % format_exc())
                 logger.error("Failed to bind entry: %s %s" % \
                              (entry.tag, entry.get('name')))
             except Exception, exc:
                 if 'failure' not in entry.attrib:
-                    entry.set('failure', 'bind error: %s' % exc)
+                    entry.set('failure', 'bind error: %s' % format_exc())
                 logger.error("Unexpected failure in BindStructure: %s %s" \
                              % (entry.tag, entry.get('name')), exc_info=1)
 
@@ -283,7 +285,8 @@ class Core(Component):
         if len(g2list) == 1:
             return g2list[0].HandleEntry(entry, metadata)
         entry.set('failure', 'no matching generator')
-        raise PluginExecutionError(entry.tag, entry.get('name'))
+        raise PluginExecutionError("No matching generator: %s:%s" %
+                                   (entry.tag, entry.get('name')))
 
     def BuildConfiguration(self, client):
         """Build configuration for clients."""
@@ -387,9 +390,9 @@ class Core(Component):
             return lxml.etree.tostring(resp, encoding='UTF-8',
                                        xml_declaration=True)
         except Bcfg2.Server.Plugins.Metadata.MetadataConsistencyError:
-            warning = 'Client metadata resolution error for %s; check server log' % address[0]
+            warning = 'Client metadata resolution error for %s' % address[0]
             self.logger.warning(warning)
-            raise xmlrpclib.Fault(6, warning)
+            raise xmlrpclib.Fault(6, warning + "; check server log")
         except Bcfg2.Server.Plugins.Metadata.MetadataRuntimeError:
             err_msg = 'Metadata system runtime failure'
             self.logger.error(err_msg)
@@ -410,7 +413,8 @@ class Core(Component):
         # clear dynamic groups
         self.metadata.cgroups[meta.hostname] = []
         try:
-            xpdata = lxml.etree.XML(probedata.encode('utf-8'))
+            xpdata = lxml.etree.XML(probedata.encode('utf-8'),
+                                    parser=Bcfg2.Server.XMLParser)
         except:
             self.logger.error("Failed to parse probe data from client %s" % \
                               (address[0]))
@@ -459,7 +463,8 @@ class Core(Component):
     @exposed
     def RecvStats(self, address, stats):
         """Act on statistics upload."""
-        sdata = lxml.etree.XML(stats.encode('utf-8'))
+        sdata = lxml.etree.XML(stats.encode('utf-8'),
+                               parser=Bcfg2.Server.XMLParser)
         client = self.metadata.resolve_client(address)
         self.process_statistics(client, sdata)
         return "<ok/>"
