@@ -8,7 +8,8 @@ __all__ = ['Bundles',
            'Pkgmgr',
            'RequiredAttrs',
            'Validate',
-           'Genshi']
+           'Genshi',
+           'Deltas']
 
 import logging
 import os
@@ -119,7 +120,9 @@ class ErrorHandler (object):
                "merge-probes":"warning",
                "input-output-error":"error",
                "genshi-syntax-error":"error",
-               "pattern-fails-to-initialize":"error"}
+               "pattern-fails-to-initialize":"error",
+               "cat-file-used":"warning",
+               "diff-file-used":"warning"}
 
     def __init__(self, config=None):
         self.errors = 0
@@ -129,11 +132,12 @@ class ErrorHandler (object):
 
         termsize = get_termsize()
         if termsize is not None:
-            self._wrapper = textwrap.TextWrapper(initial_indent="  ",
-                                                 subsequent_indent="  ",
-                                                 width=termsize[0])
+            twrap = textwrap.TextWrapper(initial_indent="  ",
+                                        subsequent_indent="  ",
+                                        width=termsize[0])
+            self._wrapper = twrap.wrap
         else:
-            self._wrapper = None
+            self._wrapper = lambda s: [s]
 
         self._handlers = {}
         if config is not None:
@@ -188,13 +192,10 @@ class ErrorHandler (object):
         rawlines = msg.splitlines()
         firstline = True
         for rawline in rawlines:
-            if self._wrapper:
-                lines = self._wrapper.wrap(rawline)
-            else:
-                lines = [rawline]
+            lines = self._wrapper(rawline)
             for line in lines:
                 if firstline:
-                    logfunc("%s%s" % (prefix, line.lstrip()))
+                    logfunc(prefix + line.lstrip())
                     firstline = False
                 else:
                     logfunc(line)
