@@ -5,16 +5,14 @@ import copy
 import logging
 import lxml.etree
 import os
-import os.path
 import pickle
 import posixpath
 import re
 import sys
 import threading
+import Bcfg2.Server
 from Bcfg2.Bcfg2Py3k import ConfigParser
 
-from lxml.etree import XML, XMLSyntaxError
-
 import Bcfg2.Options
 
 # py3k compatibility
@@ -52,6 +50,19 @@ info_regex = re.compile( \
     'perms:(\s)*(?P<perms>\w+)|' +
     'sensitive:(\s)*(?P<sensitive>\S+)|')
 
+def bind_info(entry, metadata, infoxml=None, default=default_file_metadata):
+    for attr, val in list(default.items()):
+        entry.set(attr, val)
+    if infoxml:
+        mdata = dict()
+        infoxml.pnode.Match(metadata, mdata, entry=entry)
+        if 'Info' not in mdata:
+            msg = "Failed to set metadata for file %s" % entry.get('name')
+            logger.error(msg)
+            raise PluginExecutionError(msg)
+        for attr, val in list(mdata['Info'][None].items()):
+            entry.set(attr, val)
+
 
 class PluginInitError(Exception):
     """Error raised in cases of Plugin initialization errors."""
@@ -257,7 +268,9 @@ class ThreadedStatistics(Statistics,
                     if self.terminate.isSet():
                         return False
 
-                self.work_queue.put_nowait((metadata, lxml.etree.fromstring(pdata)))
+                self.work_queue.put_nowait((metadata,
+                                            lxml.etree.XML(pdata,
+                                                           parser=Bcfg2.Server.XMLParser)))
             except Full:
                 self.logger.warning("Queue.Full: Failed to load queue data")
                 break
@@ -276,7 +289,7 @@ class ThreadedStatistics(Statistics,
     def run(self):
         if not self.load():
             return
-        while not self.terminate.isSet():
+        while not self.terminate.isSet() and self.work_queue != None:
             try:
                 (xdata, client) = self.work_queue.get(block=True, timeout=2)
             except Empty:
@@ -286,7 +299,7 @@ class ThreadedStatistics(Statistics,
                 self.logger.error("ThreadedStatistics: %s" % e)
                 continue
             self.handle_statistic(xdata, client)
-        if not self.work_queue.empty():
+        if self.work_queue != None and not self.work_queue.empty():
             self.save()
 
     def process_statistics(self, metadata, data):
@@ -572,8 +585,9 @@ class XMLFileBacked(FileBacked):
     def Index(self):
         """Build local data structures."""
         try:
-            self.xdata = XML(self.data)
-        except XMLSyntaxError:
+            self.xdata = lxml.etree.XML(self.data,
+                                        parser=Bcfg2.Server.XMLParser)
+        except lxml.etree.XMLSyntaxError:
             logger.error("Failed to parse %s" % (self.name))
             return
         self.entries = self.xdata.getchildren()
@@ -598,7 +612,8 @@ class SingleXMLFileBacked(XMLFileBacked):
     def Index(self):
         """Build local data structures."""
         try:
-            self.xdata = lxml.etree.XML(self.data, base_url=self.name)
+            self.xdata = lxml.etree.XML(self.data, base_url=self.name,
+                                        parser=Bcfg2.Server.XMLParser)
         except lxml.etree.XMLSyntaxError:
             err = sys.exc_info()[1]
             logger.error("Failed to parse %s: %s" % (self.name, err))
@@ -764,7 +779,7 @@ class XMLSrc(XMLFileBacked):
             return
         self.items = {}
         try:
-            xdata = lxml.etree.XML(data)
+            xdata = lxml.etree.XML(data, parser=Bcfg2.Server.XMLParser)
         except lxml.etree.XMLSyntaxError:
             logger.error("Failed to parse file %s" % (self.name))
             return
@@ -847,7 +862,7 @@ class PrioDir(Plugin, Generator, XMLDirectoryBacked):
                         self._matches(entry, metadata,
                                       src.cache[1][entry.tag]))]
         if len(matching) == 0:
-            raise PluginExecutionError
+            raise PluginExecutionError('No matching source for entry when retrieving attributes for %s(%s)' % (entry.tag, entry.attrib.get('name')))
         elif len(matching) == 1:
             index = 0
         else:
@@ -866,6 +881,9 @@ class PrioDir(Plugin, Generator, XMLDirectoryBacked):
             if self._matches(entry, metadata, [rname]):
                 data = matching[index].cache[1][entry.tag][rname]
                 break
+        else:
+            # Fall back on __getitem__. Required if override used
+            data = matching[index].cache[1][entry.tag][entry.get('name')]
         if '__text__' in data:
             entry.text = data['__text__']
         if '__children__' in data:
@@ -1072,18 +1090,7 @@ class EntrySet:
         return cmp(x.specific.prio, y.specific.prio)
 
     def bind_info_to_entry(self, entry, metadata):
-        # first set defaults from global metadata/:info
-        for key in self.metadata:
-            entry.set(key, self.metadata[key])
-        if self.infoxml:
-            mdata = {}
-            self.infoxml.pnode.Match(metadata, mdata, entry=entry)
-            if 'Info' not in mdata:
-                logger.error("Failed to set metadata for file %s" % \
-                             (entry.get('name')))
-                raise PluginExecutionError
-            [entry.attrib.__setitem__(key, value) \
-             for (key, value) in list(mdata['Info'][None].items())]
+        bind_info(entry, metadata, infoxml=self.infoxml, default=self.metadata)
 
     def bind_entry(self, entry, metadata):
         """Return the appropriate interpreted template from the set of available templates."""
@@ -1190,6 +1197,7 @@ class SimpleConfig(FileBacked,
         filename = os.path.join(plugin.data, plugin.name.lower() + ".conf")
         self.plugin = plugin
         self.fam = self.plugin.core.fam
+        self.read_files = set()
         Bcfg2.Server.Plugin.FileBacked.__init__(self, filename)
         ConfigParser.SafeConfigParser.__init__(self)
 
@@ -1201,30 +1209,43 @@ class SimpleConfig(FileBacked,
         """ Build local data structures """
         for section in self.sections():
             self.remove_section(section)
-        self.read(self.name)
+        self.read_files.update(self.read(self.name))
 
-    def get(self, section, option, default=None):
+    def get(self, section, option, **kwargs):
         """ convenience method for getting config items """
+        default = None
+        if 'default' in kwargs:
+            default = kwargs['default']
+            del kwargs['default']
         try:
-            return ConfigParser.SafeConfigParser.get(self, section, option)
+            return ConfigParser.SafeConfigParser.get(self, section, option,
+                                                     **kwargs)
         except (ConfigParser.NoSectionError, ConfigParser.NoOptionError):
             if default is not None:
                 return default
             else:
                 raise
 
-    def getboolean(self, section, option, default=None):
+    def getboolean(self, section, option, **kwargs):
         """ convenience method for getting boolean config items """
+        default = None
+        if 'default' in kwargs:
+            default = kwargs['default']
+            del kwargs['default']
         try:
-            return ConfigParser.SafeConfigParser.getboolean(self,
-                                                            section, option)
-        except (ConfigParser.NoSectionError, ConfigParser.NoOptionError):
-            if default is not None:
-                return default
-            else:
-                raise
-        except ValueError:
+            return ConfigParser.SafeConfigParser.getboolean(self, section,
+                                                            option, **kwargs)
+        except (ConfigParser.NoSectionError, ConfigParser.NoOptionError,
+                ValueError):
             if default is not None:
                 return default
             else:
                 raise
+
+    @property
+    def loaded(self):
+        if os.path.exists(self.name):
+            return self.name in self.read_files
+        else:
+            return True
+            
