@@ -7,7 +7,7 @@ import glob
 import socket
 import logging
 import lxml.etree
-
+import Bcfg2.Server
 import Bcfg2.Server.Plugin
 
 LOGGER = logging.getLogger('Bcfg2.Plugins.NagiosGen')
@@ -52,7 +52,12 @@ class NagiosGen(Bcfg2.Server.Plugin.Plugin,
 
     def createhostconfig(self, entry, metadata):
         """Build host specific configuration file."""
-        host_address = socket.gethostbyname(metadata.hostname)
+        try:
+            host_address = socket.gethostbyname(metadata.hostname)
+        except socket.gaierror:
+            LOGGER.error("Failed to find IP address for %s" %
+                         metadata.hostname)
+            raise Bcfg2.Server.Plugin.PluginExecutionError
         host_groups = [grp for grp in metadata.groups
                        if os.path.isfile('%s/%s-group.cfg' % (self.data, grp))]
         host_config = ['define host {',
@@ -85,7 +90,8 @@ class NagiosGen(Bcfg2.Server.Plugin.Plugin,
             LOGGER.warn("Parsing deprecated NagiosGen/parents.xml. "
                         "Update to the new-style config with "
                         "nagiosgen-convert.py.")
-            parents = lxml.etree.parse(pfile)
+            parents = lxml.etree.parse(pfile,
+                                       parser=Bcfg2.Server.XMLParser)
             for el in parents.xpath("//Depend[@name='%s']" % metadata.hostname):
                 if 'parent' in xtra:
                     xtra['parent'] += "," + el.get("on")
