@@ -19,8 +19,19 @@ except:
         raise ImportError
 
 
-class OhaiCache(object):
+probecode = """#!/bin/sh
 
+export PATH=$PATH:/sbin:/usr/sbin
+
+if type ohai >& /dev/null; then
+    ohai
+else
+    # an empty dict, so "'foo' in metadata.Ohai" tests succeed
+    echo '{}'
+fi
+"""
+
+class OhaiCache(object):
     def __init__(self, dirname):
         self.dirname = dirname
         self.cache = dict()
@@ -37,12 +48,12 @@ class OhaiCache(object):
             try:
                 data = open("%s/%s.json" % (self.dirname, item)).read()
             except:
-                raise KeyError, item
+                raise KeyError(item)
             self.cache[item] = json.loads(data)
         return self.cache[item]
 
     def __iter__(self):
-        data = self.cache.keys()
+        data = list(self.cache.keys())
         data.extend([x[:-5] for x in os.listdir(self.dirname)])
         return data.__iter__()
 
@@ -50,7 +61,9 @@ class OhaiCache(object):
 class Ohai(Bcfg2.Server.Plugin.Plugin,
            Bcfg2.Server.Plugin.Probing,
            Bcfg2.Server.Plugin.Connector):
-    """The Ohai plugin is used to detect information about the client operating system."""
+    """The Ohai plugin is used to detect information
+    about the client operating system.
+    """
     name = 'Ohai'
     experimental = True
 
@@ -60,7 +73,7 @@ class Ohai(Bcfg2.Server.Plugin.Plugin,
         Bcfg2.Server.Plugin.Connector.__init__(self)
         self.probe = lxml.etree.Element('probe', name='Ohai', source='Ohai',
                                         interpreter='/bin/sh')
-        self.probe.text = 'ohai'
+        self.probe.text = probecode
         try:
             os.stat(self.data)
         except:
