@@ -4,17 +4,17 @@ import time
 import copy
 import glob
 import socket
-import random
 import logging
 import threading
 import lxml.etree
 from UserDict import DictMixin
 from subprocess import Popen, PIPE, STDOUT
 import Bcfg2.Server.Plugin
-from Bcfg2.Bcfg2Py3k import StringIO, cPickle, HTTPError, ConfigParser, file
+from Bcfg2.Bcfg2Py3k import StringIO, cPickle, HTTPError, URLError, ConfigParser, file
 from Bcfg2.Server.Plugins.Packages.Collection import Collection
 from Bcfg2.Server.Plugins.Packages.Source import SourceInitError, Source, \
      fetch_url
+from Bcfg2.Server.Plugins.Packages.PackagesConfig import PackagesConfig
 
 logger = logging.getLogger(__name__)
 
@@ -52,23 +52,23 @@ PULPCONFIG = None
 def _setup_pulp(config):
     global PULPSERVER, PULPCONFIG
     if not has_pulp:
-        logger.error("Packages: Cannot create Pulp collection: Pulp libraries not "
-                     "found")
-        raise Bcfg2.Server.Plugin.PluginInitError
+        msg = "Packages: Cannot create Pulp collection: Pulp libraries not found"
+        logger.error(msg)
+        raise Bcfg2.Server.Plugin.PluginInitError(msg)
 
     if PULPSERVER is None:
         try:
             username = config.get("pulp", "username")
             password = config.get("pulp", "password")
         except ConfigParser.NoSectionError:
-            logger.error("Packages: No [pulp] section found in Packages/packages.conf")
-            raise Bcfg2.Server.Plugin.PluginInitError
+            msg = "Packages: No [pulp] section found in Packages/packages.conf"
+            logger.error(msg)
+            raise Bcfg2.Server.Plugin.PluginInitError(msg)
         except ConfigParser.NoOptionError:
-            err = sys.exc_info()[1]
-            logger.error("Packages: Required option not found in "
-                         "Packages/packages.conf: %s" % err)
-            raise Bcfg2.Server.Plugin.PluginInitError
-        
+            msg = "Packages: Required option not found in Packages/packages.conf: %s" % sys.exc_info()[1]
+            logger.error(msg)
+            raise Bcfg2.Server.Plugin.PluginInitError(msg)
+
         PULPCONFIG = ConsumerConfig()
         serveropts = PULPCONFIG.server
         
@@ -91,12 +91,9 @@ class YumCollection(Collection):
         self.keypath = os.path.join(self.basepath, "keys")
 
         if len(sources):
-            config = sources[0].config
-            self.use_yum = has_yum and config.getboolean("yum",
-                                                         "use_yum_libraries",
-                                                         default=False)
+            self.config = sources[0].config
         else:
-            self.use_yum = False
+            self.config = PackageConfig('Packages')
 
         if self.use_yum:
             self.cachefile = os.path.join(self.cachepath,
@@ -110,12 +107,41 @@ class YumCollection(Collection):
             self.cfgfile = os.path.join(self.configdir,
                                         "%s-yum.conf" % self.cachekey)
             self.write_config()
-
-            self.helper = self.config.get("yum", "helper",
-                                          default="/usr/sbin/bcfg2-yum-helper")
-        if has_pulp:
+        if has_pulp and self.has_pulp_sources:
             _setup_pulp(self.config)
 
+        self._helper = None
+
+    @property
+    def helper(self):
+        try:
+            return self.config.get("yum", "helper")
+        except:
+            pass
+
+        if not self._helper:
+            # first see if bcfg2-yum-helper is in PATH
+            try:
+                Popen(['bcfg2-yum-helper'],
+                      stdin=PIPE, stdout=PIPE, stderr=PIPE).wait()
+                self._helper = 'bcfg2-yum-helper'
+            except OSError:
+                self._helper = "/usr/sbin/bcfg2-yum-helper"
+        return self._helper
+
+    @property
+    def use_yum(self):
+        return has_yum and self.config.getboolean("yum", "use_yum_libraries",
+                                                  default=False)
+
+    @property
+    def has_pulp_sources(self):
+        """ see if there are any pulp sources to handle """
+        for source in self.sources:
+            if source.pulp_id:
+                return True
+        return False
+
     def write_config(self):
         if not os.path.exists(self.cfgfile):
             yumconf = self.get_config(raw=True)
@@ -178,6 +204,13 @@ class YumCollection(Collection):
                         config.set(reponame, "includepkgs",
                                    " ".join(source.whitelist))
 
+                    if raw:
+                        opts = source.server_options
+                    else:
+                        opts = source.client_options
+                    for opt, val in opts.items():
+                        config.set(reponame, opt, val)
+
         if raw:
             return config
         else:
@@ -197,8 +230,21 @@ class YumCollection(Collection):
                 needkeys.add(key)
 
         if len(needkeys):
-            keypkg = lxml.etree.Element('BoundPackage', name="gpg-pubkey",
-                                        type=self.ptype, origin='Packages')
+            if has_yum:
+                # this must be be has_yum, not use_yum, because
+                # regardless of whether the user wants to use the yum
+                # resolver we want to include gpg key data
+                keypkg = lxml.etree.Element('BoundPackage', name="gpg-pubkey",
+                                            type=self.ptype, origin='Packages')
+            else:
+                self.logger.warning("GPGKeys were specified for yum sources in "
+                                    "sources.xml, but no yum libraries were "
+                                    "found")
+                self.logger.warning("GPG key version/release data cannot be "
+                                    "determined automatically")
+                self.logger.warning("Install yum libraries, or manage GPG keys "
+                                    "manually")
+                keypkg = None
 
             for key in needkeys:
                 # figure out the path of the key on the client
@@ -219,16 +265,10 @@ class YumCollection(Collection):
                 # hook to add version/release info if possible
                 self._add_gpg_instances(keypkg, kdata, localkey, remotekey)
                 independent.append(keypath)
-            independent.append(keypkg)
+            if keypkg is not None:
+                independent.append(keypkg)
 
-        # see if there are any pulp sources to handle
-        has_pulp_sources = False
-        for source in self.sources:
-            if source.pulp_id:
-                has_pulp_sources = True
-                break
-
-        if has_pulp_sources:
+        if self.has_pulp_sources:
             consumerapi = ConsumerAPI()
             consumer = self._get_pulp_consumer(consumerapi=consumerapi)
             if consumer is None:
@@ -274,20 +314,25 @@ class YumCollection(Collection):
     def _add_gpg_instances(self, keyentry, keydata, localkey, remotekey):
         """ add gpg keys to the specification to ensure they get
         installed """
-        if self.use_yum:
-            try:
-                kinfo = yum.misc.getgpgkeyinfo(keydata)
-                version = yum.misc.keyIdToRPMVer(kinfo['keyid'])
-                release = yum.misc.keyIdToRPMVer(kinfo['timestamp'])
-                
-                lxml.etree.SubElement(keyentry, 'Instance',
-                                      version=version,
-                                      release=release,
-                                      simplefile=remotekey)
-            except ValueError:
-                err = sys.exc_info()[1]
-                self.logger.error("Packages: Could not read GPG key %s: %s" %
-                                  (localkey, err))
+        # this must be be has_yum, not use_yum, because regardless of
+        # whether the user wants to use the yum resolver we want to
+        # include gpg key data
+        if not has_yum:
+            return
+        
+        try:
+            kinfo = yum.misc.getgpgkeyinfo(keydata)
+            version = yum.misc.keyIdToRPMVer(kinfo['keyid'])
+            release = yum.misc.keyIdToRPMVer(kinfo['timestamp'])
+            
+            lxml.etree.SubElement(keyentry, 'Instance',
+                                  version=version,
+                                  release=release,
+                                  simplefile=remotekey)
+        except ValueError:
+            err = sys.exc_info()[1]
+            self.logger.error("Packages: Could not read GPG key %s: %s" %
+                              (localkey, err))
 
     def is_package(self, package):
         if not self.use_yum:
@@ -396,10 +441,8 @@ class YumCollection(Collection):
             self.logger.error("Packages: error running bcfg2-yum-helper "
                               "(returned %d): %s" % (rv, stderr))
         elif self.debug_flag:
-            self.logger.debug("Packages: debug info from bcfg2-yum-helper: %s" %
-                              stderr)
-            self.logger.debug("Packages: output from bcfg2-yum-helper: %s" %
-                              stderr)
+            self.debug_log("Packages: debug info from bcfg2-yum-helper: %s" %
+                           stderr)
         try:
             return json.loads(stdout)
         except ValueError:
@@ -438,19 +481,18 @@ class YumSource(Source):
             repoapi = RepositoryAPI()
             try:
                 self.repo = repoapi.repository(self.pulp_id)
-                self.gpgkeys = ["%s/%s" % (PULPCONFIG.cds['keyurl'], key)
+                self.gpgkeys = [os.path.join(PULPCONFIG.cds['keyurl'], key)
                                 for key in repoapi.listkeys(self.pulp_id)]
             except server.ServerRequestError:
                 err = sys.exc_info()[1]
                 if err[0] == 401:
                     msg = "Packages: Error authenticating to Pulp: %s" % err[1]
                 elif err[0] == 404:
-                    msg = "Packages: Pulp repo id %s not found: %s" % (self.pulp_id,
-                                                             err[1])
+                    msg = "Packages: Pulp repo id %s not found: %s" % \
+                          (self.pulp_id, err[1])
                 else:
-                    msg = "Packages: Error %d fetching pulp repo %s: %s" % (err[0],
-                                                                  self.pulp_id,
-                                                                  err[1])
+                    msg = "Packages: Error %d fetching pulp repo %s: %s" % \
+                          (err[0], self.pulp_id, err[1])
                 raise SourceInitError(msg)
             except socket.error:
                 err = sys.exc_info()[1]
@@ -475,8 +517,10 @@ class YumSource(Source):
         self.needed_paths = set()
         self.file_to_arch = dict()
 
-        self.use_yum = has_yum and config.getboolean("yum", "use_yum_libraries",
-                                                     default=False)
+    @property
+    def use_yum(self):
+        return has_yum and self.config.getboolean("yum", "use_yum_libraries",
+                                                  default=False)
 
     def save_state(self):
         if not self.use_yum:
@@ -526,6 +570,11 @@ class YumSource(Source):
         except ValueError:
             self.logger.error("Packages: Bad url string %s" % rmdurl)
             return []
+        except URLError:
+            err = sys.exc_info()[1]
+            self.logger.error("Packages: Failed to fetch url %s. %s" %
+                              (rmdurl, err))
+            return []
         except HTTPError:
             err = sys.exc_info()[1]
             self.logger.error("Packages: Failed to fetch url %s. code=%s" %
