@@ -47,6 +47,10 @@ class Packages(Bcfg2.Server.Plugin.Plugin,
 
     @property
     def disableResolver(self):
+        if self.disableMetaData:
+            # disabling metadata without disabling the resolver Breaks
+            # Things
+            return True
         try:
             return not self.config.getboolean("global", "resolver")
         except (ConfigParser.NoSectionError, ConfigParser.NoOptionError):
@@ -87,7 +91,9 @@ class Packages(Bcfg2.Server.Plugin.Plugin,
     def HandleEntry(self, entry, metadata):
         if entry.tag == 'Package':
             collection = self._get_collection(metadata)
-            entry.set('version', 'auto')
+            entry.set('version', self.config.get("global",
+                                                 "version",
+                                                 default="auto"))
             entry.set('type', collection.ptype)
         elif entry.tag == 'Path':
             if (entry.get("name") == self.config.get("global", "yum_config",
@@ -178,8 +184,9 @@ class Packages(Bcfg2.Server.Plugin.Plugin,
         newpkgs.sort()
         for pkg in newpkgs:
             lxml.etree.SubElement(independent, 'BoundPackage', name=pkg,
-                                  version='auto', type=collection.ptype,
-                                  origin='Packages')
+                                  version=self.config.get("global", "version",
+                                                          default="auto"),
+                                  type=collection.ptype, origin='Packages')
 
     def Refresh(self):
         '''Packages.Refresh() => True|False\nReload configuration
