@@ -5,7 +5,10 @@ import logging
 import re
 import Bcfg2.Server.Plugin
 import lxml
-from sets import Set
+try:
+    set
+except NameError:
+    from sets import Set as set
 
 logger = logging.getLogger('Bcfg2.Plugins.Pkgmgr')
 
@@ -22,12 +25,14 @@ class FuzzyDict(dict):
             print("got non-string key %s" % str(key))
         return dict.__getitem__(self, key)
 
-    def has_key(self, key):
+    def __contains__(self, key):
         if isinstance(key, str):
             mdata = self.fuzzy.match(key)
-            if self.fuzzy.match(key):
-                return dict.has_key(self, mdata.groupdict()['name'])
-        return dict.has_key(self, key)
+            if mdata:
+                return dict.__contains__(self, mdata.groupdict()['name'])
+        else:
+            print("got non-string key %s" % str(key))
+        return dict.__contains__(self, key)
 
     def get(self, key, default=None):
         try:
@@ -64,7 +69,7 @@ class PNode(Bcfg2.Server.Plugin.INode):
         if 'Package' not in pdict:
             pdict['Package'] = set()
         for child in data.getchildren():
-            attrs = Set(data.attrib.keys()).difference(child.attrib.keys() + ['name'])
+            attrs = set(data.attrib.keys()).difference(child.attrib.keys() + ['name'])
             for attr in attrs:
                 try:
                     child.set(attr, data.get(attr))
